#[repr(isize)]pub enum CFComparisonResult {
LessThan = -1,
EqualTo = 0,
GreaterThan = 1,
}Expand description
Constants returned by comparison functions, indicating sort order.
See documentation.
Variants
LessThan = -1
The first value is less than the second value.
EqualTo = 0
The first value is equal to the second value.
GreaterThan = 1
The first value is greater than the second value.
Implementations
Sourceimpl CFComparisonResult
impl CFComparisonResult
Sourcepub fn into_ordering(self) -> Ordering
pub fn into_ordering(self) -> Ordering
Converts this comparison result into a Rust ordering.