Module core_services

Module core_services 

Core Services framework.

Feature Flag

This module corresponds to the core_services feature flag.

Documentation

Modules

sys
Raw unsafe C functions exposed by CoreServices.framework.

Structs

AEDescType
Specifies the type of the data stored in an AEDesc descriptor.
AEEventClass
Specifies the event class of an Apple event.
AEEventID
Specifies the event ID of an Apple event.
AEReturnID
Specifies a return ID for a created Apple event.
AESendMode
Specify send preferences to the AESend function.
AETransactionID
Specifies a transaction ID.

Type Aliases

AEDataStorage
A pointer to an opaque data type that provides storage for an AEDesc descriptor.
AEDataStorageType
An opaque data type used to store data in Apple event descriptors.