NSNull

Struct NSNull 

#[repr(C)]
pub struct NSNull(/* private fields */);
A singleton object used to represent null values in collection objects that don’t allow nil values.

See documentation.

Implementations

Source

impl NSNull

pub fn null() -> &'static Self

Returns the singleton instance.

See documentation.

Methods from Deref<Target = NSObject<'static>>

pub fn retain_count(&self) -> usize

Returns this object’s reference count.

This method is only useful for debugging certain objects.

See documentation.

pub fn responds_to_selector(&self, selector: Sel) -> bool

Returns true if this object implements or inherits a method that can respond to a specified message.

See documentation.

pub fn is_kind_of_class(&self, class: &Class) -> bool

Returns true if this object is an instance or subclass of class.

See documentation

pub fn is_member_of_class(&self, class: &Class) -> bool

Returns true if this object is an instance of class.

See documentation

pub fn hash(&self) -> NSUInteger

Returns an integer that can be used as a table address in a hash table structure.

See documentation.

pub fn copy(&self) -> Arc<Self>

Returns a copy of this object using NSCopying.

See documentation.

pub fn mutable_copy(&self) -> Arc<Self>

Returns a copy of this object using NSMutableCopying.

See documentation.

pub fn description(&self) -> Arc<NSString<'static>>

Returns a string that describes the contents of this object.

See documentation

pub fn debug_description(&self) -> Arc<NSString<'static>>

Returns a string that describes the contents of the receiver for presentation in the debugger.

See documentation