Core Services framework.
Feature Flag
This module corresponds to the core_services
feature flag.
Documentation
Modules
- sys
- Raw unsafe C functions exposed by
CoreServices.framework.
Structs
- AEDesc
Type - Specifies the type of the data stored in an
AEDescdescriptor. - AEEvent
Class - Specifies the event class of an Apple event.
- AEEventID
- Specifies the event ID of an Apple event.
- AEReturnID
- Specifies a return ID for a created Apple event.
- AESend
Mode - Specify send preferences to the
AESendfunction. - AETransactionID
- Specifies a transaction ID.
Type Aliases
- AEData
Storage - A pointer to an opaque data type that provides storage for an
AEDescdescriptor. - AEData
Storage Type - An opaque data type used to store data in Apple event descriptors.